'use strict';

var rollupPluginutils = require('rollup-pluginutils');

/*
 * create a style tag and append to head tag
 * @params {String} css style
 */

function insertStyle ( css ) {
    if(!css) return ;

    if(typeof(window) == 'undefined') return ;
    let style = document.createElement('style');

    style.innerHTML = css;
    document.head.appendChild(style);
    return css;
}

function userScriptCss(options = {}) {
  if (typeof options.insert === 'undefined') {
    options.insert = true;
  }

  const filter = rollupPluginutils.createFilter(options.include || ['**/*.css'], options.exclude || 'node_modules/**');

  const injectFnName = '__$styleInject';
  let codeCount = 0;

  return {
    name: 'userscriptCss',
    intro() {
      return options.insert && codeCount ? insertStyle.toString().replace(/insertStyle/, injectFnName) : '';
    },

    transform(code, id) {
      if (!filter(id)) return;

      let exportCode = '';

      if (options.insert != false) {
        codeCount += 1;
        exportCode = `export default ${injectFnName}(${JSON.stringify(code)});`;
      } else {
        exportCode = `export default ${JSON.stringify(code.toString())};`;
      }

      return {
        code: exportCode,
        map: { mappings: '' }
      };
    }
  }
}

module.exports = userScriptCss;
